// compileCompressed: $1.css
/*!
 * Plugin:	Rank Math - 404 Monitor
 * URL:		https://rankmath.com/wordpress/plugin/seo-suite/
 * Name:	404-monitor.css
 */


.metabox-prefs legend + label {
	display: none;
}
