<?php
/**
 * Reports API Client class for MonsterInsights.
 *
 * This class is intended to handle API requests related to fetching reports
 * from the MonsterInsights service. It extends the base API client.
 *
 *
 * @package MonsterInsights
 */
class MonsterInsights_API_Reports extends MonsterInsights_API_Client {

} 