<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Http;

use WPForms\Vendor\Core\Types\Sdk\CoreCallback;
/**
 * HttpCallBack allows defining callables for pre and post API calls.
 */
class HttpCallBack extends CoreCallback
{
}
