<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * An enum identifier of the device type.
 */
class DeviceAttributesDeviceType
{
    public const TERMINAL = 'TERMINAL';
}
