/*!***************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[4].use[1]!./node_modules/postcss-loader/dist/cjs.js??ruleSet[1].rules[4].use[2]!./node_modules/sass-loader/dist/cjs.js??ruleSet[1].rules[4].use[3]!./src/assets/scss/monsterinsights/frontend-Lite.scss ***!
  \***************************************************************************************************************************************************************************************************************************************************************************/
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled img {
  max-width: 100%;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled a.monsterinsights-inline-popular-posts-title {
  text-decoration: none;
  box-shadow: none;
  font-style: normal;
  font-weight: bold;
  border: none;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled a.monsterinsights-inline-popular-posts-title:hover, .monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled a.monsterinsights-inline-popular-posts-title:focus {
  text-decoration: underline;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-alpha {
  padding: 24px 27px;
  margin-bottom: 24px;
  background: #F0F2F4;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-alpha .monsterinsights-inline-popular-posts-label {
  font-size: 18px;
  line-height: 1;
  display: block;
  margin-bottom: 6px;
  color: #EB5757;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-alpha .monsterinsights-inline-popular-posts-title {
  line-height: 1;
  color: #393F4C;
  font-size: 18px;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-beta {
  padding: 14px;
  border-width: 1px;
  border-style: solid;
  border-color: #F0F2F4;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-beta .monsterinsights-inline-popular-posts-label {
  display: block;
  font-size: 18px;
  line-height: 18px;
  color: #eb5757;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-beta .monsterinsights-inline-popular-posts-text {
  display: inline-block;
  vertical-align: middle;
  width: calc(100% - 164px);
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-beta .monsterinsights-inline-popular-posts-title {
  line-height: 130%;
  color: #393F4C;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-beta .monsterinsights-inline-popular-posts-image {
  width: 144px;
  padding: 0;
  display: inline-block;
  margin-right: 19px;
  vertical-align: middle;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-charlie .monsterinsights-inline-popular-posts-label {
  display: block;
  font-size: 16px;
  line-height: 1.1;
  color: #393F4C;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-charlie .monsterinsights-inline-popular-posts-text {
  display: block;
  vertical-align: middle;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-charlie .monsterinsights-inline-popular-posts-post {
  display: list-item;
  margin-left: 20px;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-charlie .monsterinsights-inline-popular-posts-title {
  line-height: 130%;
  font-weight: 400;
  color: #393F4C;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-charlie .monsterinsights-inline-popular-posts-image {
  width: 144px;
  padding: 0;
  display: inline-block;
}
.monsterinsights-inline-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-inline-popular-posts-charlie .monsterinsights-inline-popular-posts-border {
  display: block;
  border-style: solid;
  border-width: 0 0 1px;
  margin: 16px 0;
  border-color: #D3D7DE;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled {
  margin-bottom: 24px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled img {
  max-width: 100%;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled .monsterinsights-widget-popular-posts-title,
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled .monsterinsights-widget-popular-posts-list a {
  text-decoration: none;
  color: #393F4C;
  box-shadow: none;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled .monsterinsights-widget-popular-posts-list a:hover .monsterinsights-widget-popular-posts-title, .monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled .monsterinsights-widget-popular-posts-list a:focus .monsterinsights-widget-popular-posts-title {
  text-decoration: underline;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-alpha .monsterinsights-widget-popular-posts-list {
  margin: 0 -6px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-alpha .monsterinsights-widget-popular-posts-list li {
  display: inline-block;
  padding: 24px;
  background: #f0f2f4;
  border-radius: 3px;
  margin: 0 6px 12px 6px;
  width: calc(50% - 12px);
  vertical-align: top;
  font-size: 16px;
  line-height: 1.2;
  color: #393f4c;
  font-weight: 700;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-beta .monsterinsights-widget-popular-posts-list {
  margin: 0 -6px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-beta .monsterinsights-widget-popular-posts-list li {
  display: inline-block;
  background: #fff;
  border-radius: 3px;
  margin: 0 6px 30px 6px;
  width: calc(50% - 12px);
  vertical-align: top;
  font-size: 16px;
  line-height: 1.2;
  color: #393f4c;
  font-weight: 700;
  border-left: 4px solid #1ec185;
  padding-left: 16px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-charlie .monsterinsights-widget-popular-posts-list {
  margin: 0 -6px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-charlie .monsterinsights-widget-popular-posts-list li {
  display: inline-block;
  padding: 24px;
  background: #f0f2f4;
  border-radius: 3px;
  margin: 0 6px 12px 6px;
  width: calc(50% - 12px);
  vertical-align: top;
  font-size: 16px;
  line-height: 1.2;
  color: #393f4c;
  font-weight: 700;
  border-top: 4px solid #338eef;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled .monsterinsights-widget-popular-posts-list {
  padding: 0;
  margin: 0 -6px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled .monsterinsights-widget-popular-posts-list li {
  width: calc(50% - 12px);
  margin-left: 6px;
  margin-right: 6px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-1 .monsterinsights-widget-popular-posts-list {
  margin: 0;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-1 .monsterinsights-widget-popular-posts-list li {
  width: 100%;
  margin-left: 0;
  margin-right: 0;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-2 .monsterinsights-widget-popular-posts-list {
  display: grid;
  grid-template-columns: repeat(2, 1fr);
  gap: 24px 12px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-2 .monsterinsights-widget-popular-posts-list li {
  margin: 0 !important;
  box-sizing: border-box;
  width: 100%;
  list-style: none;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-3 .monsterinsights-widget-popular-posts-list {
  margin: 0;
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 24px 12px;
}
.monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-3 .monsterinsights-widget-popular-posts-list li {
  margin: 0 !important;
  box-sizing: border-box;
  width: 100%;
  list-style: none;
}
@media (max-width: 767px) {
  .monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-3 .monsterinsights-widget-popular-posts-list, .monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-2 .monsterinsights-widget-popular-posts-list {
    margin: 0;
  }
  .monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-3 .monsterinsights-widget-popular-posts-list li, .monsterinsights-widget-popular-posts.monsterinsights-popular-posts-styled.monsterinsights-widget-popular-posts-columns-2 .monsterinsights-widget-popular-posts-list li {
    width: 100%;
    margin-left: 0;
    margin-right: 0;
  }
}

/*# sourceMappingURL=frontend-style.css.map*/