.monsterinsights-label-block,
.monsterinsights-radio-icons {
	display: block;
}

.monsterinsights-radio-icons {
	margin: 4px 0;
}

.monsterinsights-radio-icons * {
	box-sizing: border-box;
}

.monsterinsights-radio-icons > label {
	display: inline-block;
}

.monsterinsights-radio-icons input[type="radio"] {
	visibility: hidden;
	display: none;
}

.monsterinsights-wide-column {
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	border: 1px solid #b7c9d9;
	border-radius: 5px;
	width: 40px;
	height: 40px;
	padding: 10px 5px;
	-ms-flex-flow: wrap;
	flex-flow: wrap;
	-webkit-box-pack: justify;
	-ms-flex-pack: justify;
	justify-content: space-between;
	margin-right: 4px;
}

.monsterinsights-wide-column > span {
	background: #99a1b2;
	display: inline-block;
	width: 8px;
	height: 8px;
	border-radius: 1px;
	margin-bottom: 2px;
}

.monsterinsights-wide-column.monsterinsights-wide-column-two > span {
	width: 12px;
}

.monsterinsights-radio-icons input[type="radio"]:checked + .monsterinsights-wide-column {
	border: 2px solid #338eef;
	background: #ecf4fe;
	padding: 9px 4px;
}

.monsterinsights-radio-icons input[type="radio"]:checked + .monsterinsights-wide-column > span {
	background: #338eef;
}

.monsterinsights-wide-column.monsterinsights-wide-column-one > span {
	width: 100%;
}

.monsterinsights-field-description {
	font-family: Helvetica Neue, serif;
	font-style: italic;
	font-weight: normal;
	font-size: 13px;
	line-height: 1.5%;
	color: #545C66;
}

/** SELECT2 Styles **/
.select300-container {
	box-sizing: border-box;
	display: inline-block;
	margin: 0;
	position: relative;
	vertical-align: middle
}

.select300-container .select300-selection--single {
	box-sizing: border-box;
	cursor: pointer;
	display: block;
	height: 28px;
	user-select: none;
	-webkit-user-select: none
}

.select300-container .select300-selection--single .select300-selection__rendered {
	display: block;
	padding-left: 8px;
	padding-right: 20px;
	overflow: hidden;
	text-overflow: ellipsis;
	white-space: nowrap
}

.select300-container .select300-selection--single .select300-selection__clear {
	position: relative
}

.select300-container[dir="rtl"] .select300-selection--single .select300-selection__rendered {
	padding-right: 8px;
	padding-left: 20px
}

.select300-container .select300-selection--multiple {
	box-sizing: border-box;
	cursor: pointer;
	display: block;
	min-height: 32px;
	user-select: none;
	-webkit-user-select: none
}

.select300-container .select300-selection--multiple .select300-selection__rendered {
	display: inline-block;
	overflow: hidden;
	padding-left: 8px;
	text-overflow: ellipsis;
	white-space: nowrap
}

.select300-container .select300-search--inline {
	float: left
}

.select300-container .select300-search--inline .select300-search__field {
	box-sizing: border-box;
	border: none;
	font-size: 100%;
	margin-top: 5px;
	padding: 0
}

.select300-container .select300-search--inline .select300-search__field::-webkit-search-cancel-button {
	-webkit-appearance: none
}

.select300-dropdown {
	background-color: white;
	border: 1px solid #aaa;
	border-radius: 4px;
	box-sizing: border-box;
	display: block;
	position: absolute;
	left: -100000px;
	width: 100%;
	z-index: 1051
}

.select300-results {
	display: block
}

.select300-results__options {
	list-style: none;
	margin: 0;
	padding: 0
}

.select300-results__option {
	padding: 6px;
	user-select: none;
	-webkit-user-select: none
}

.select300-results__option[aria-selected] {
	cursor: pointer
}

.select300-container--open .select300-dropdown {
	left: 0
}

.select300-container--open .select300-dropdown--above {
	border-bottom: none;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0
}

.select300-container--open .select300-dropdown--below {
	border-top: none;
	border-top-left-radius: 0;
	border-top-right-radius: 0
}

.select300-search--dropdown {
	display: block;
	padding: 4px
}

.select300-search--dropdown .select300-search__field {
	padding: 4px;
	width: 100%;
	box-sizing: border-box
}

.select300-search--dropdown .select300-search__field::-webkit-search-cancel-button {
	-webkit-appearance: none
}

.select300-search--dropdown.select300-search--hide {
	display: none
}

.select300-close-mask {
	border: 0;
	margin: 0;
	padding: 0;
	display: block;
	position: fixed;
	left: 0;
	top: 0;
	min-height: 100%;
	min-width: 100%;
	height: auto;
	width: auto;
	opacity: 0;
	z-index: 99;
	background-color: #fff;
	filter: alpha(opacity=0)
}

.select300-hidden-accessible {
	border: 0 !important;
	clip: rect(0 0 0 0) !important;
	-webkit-clip-path: inset(50%) !important;
	clip-path: inset(50%) !important;
	height: 1px !important;
	overflow: hidden !important;
	padding: 0 !important;
	position: absolute !important;
	width: 1px !important;
	white-space: nowrap !important
}

.select300-container--default .select300-selection--single {
	background-color: #fff;
	border: 1px solid #aaa;
	border-radius: 4px
}

.select300-container--default .select300-selection--single .select300-selection__rendered {
	color: #444;
	line-height: 28px
}

.select300-container--default .select300-selection--single .select300-selection__clear {
	cursor: pointer;
	float: right;
	font-weight: bold
}

.select300-container--default .select300-selection--single .select300-selection__placeholder {
	color: #999
}

.select300-container--default .select300-selection--single .select300-selection__arrow {
	height: 26px;
	position: absolute;
	top: 1px;
	right: 1px;
	width: 20px
}

.select300-container--default .select300-selection--single .select300-selection__arrow b {
	border-color: #888 transparent transparent transparent;
	border-style: solid;
	border-width: 5px 4px 0 4px;
	height: 0;
	left: 50%;
	margin-left: -4px;
	margin-top: -2px;
	position: absolute;
	top: 50%;
	width: 0
}

.select300-container--default[dir="rtl"] .select300-selection--single .select300-selection__clear {
	float: left
}

.select300-container--default[dir="rtl"] .select300-selection--single .select300-selection__arrow {
	left: 1px;
	right: auto
}

.select300-container--default.select300-container--disabled .select300-selection--single {
	background-color: #eee;
	cursor: default
}

.select300-container--default.select300-container--disabled .select300-selection--single .select300-selection__clear {
	display: none
}

.select300-container--default.select300-container--open .select300-selection--single .select300-selection__arrow b {
	border-color: transparent transparent #888 transparent;
	border-width: 0 4px 5px 4px
}

.select300-container--default .select300-selection--multiple {
	background-color: white;
	border: 1px solid #aaa;
	border-radius: 4px;
	cursor: text
}

.select300-container--default .select300-selection--multiple .select300-selection__rendered {
	box-sizing: border-box;
	list-style: none;
	margin: 0;
	padding: 0 5px;
	width: 100%
}

.select300-container--default .select300-selection--multiple .select300-selection__rendered li {
	list-style: none
}

.select300-container--default .select300-selection--multiple .select300-selection__clear {
	cursor: pointer;
	float: right;
	font-weight: bold;
	margin-top: 5px;
	margin-right: 10px;
	padding: 1px
}

.select300-container--default .select300-selection--multiple .select300-selection__choice {
	background-color: #e4e4e4;
	border: 1px solid #aaa;
	border-radius: 4px;
	cursor: default;
	float: left;
	margin-right: 5px;
	margin-top: 5px;
	padding: 0 5px
}

.select300-container--default .select300-selection--multiple .select300-selection__choice__remove {
	color: #999;
	cursor: pointer;
	display: inline-block;
	font-weight: bold;
	margin-right: 2px
}

.select300-container--default .select300-selection--multiple .select300-selection__choice__remove:hover {
	color: #333
}

.select300-container--default[dir="rtl"] .select300-selection--multiple .select300-selection__choice, .select300-container--default[dir="rtl"] .select300-selection--multiple .select300-search--inline {
	float: right
}

.select300-container--default[dir="rtl"] .select300-selection--multiple .select300-selection__choice {
	margin-left: 5px;
	margin-right: auto
}

.select300-container--default[dir="rtl"] .select300-selection--multiple .select300-selection__choice__remove {
	margin-left: 2px;
	margin-right: auto
}

.select300-container--default.select300-container--focus .select300-selection--multiple {
	border: solid black 1px;
	outline: 0
}

.select300-container--default.select300-container--disabled .select300-selection--multiple {
	background-color: #eee;
	cursor: default
}

.select300-container--default.select300-container--disabled .select300-selection__choice__remove {
	display: none
}

.select300-container--default.select300-container--open.select300-container--above .select300-selection--single, .select300-container--default.select300-container--open.select300-container--above .select300-selection--multiple {
	border-top-left-radius: 0;
	border-top-right-radius: 0
}

.select300-container--default.select300-container--open.select300-container--below .select300-selection--single, .select300-container--default.select300-container--open.select300-container--below .select300-selection--multiple {
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0
}

.select300-container--default .select300-search--dropdown .select300-search__field {
	border: 1px solid #aaa
}

.select300-container--default .select300-search--inline .select300-search__field {
	background: transparent;
	border: none;
	outline: 0;
	box-shadow: none;
	-webkit-appearance: textfield
}

.select300-container--default .select300-results > .select300-results__options {
	max-height: 200px;
	overflow-y: auto
}

.select300-container--default .select300-results__option[role=group] {
	padding: 0
}

.select300-container--default .select300-results__option[aria-disabled=true] {
	color: #999
}

.select300-container--default .select300-results__option[aria-selected=true] {
	background-color: #ddd
}

.select300-container--default .select300-results__option .select300-results__option {
	padding-left: 1em
}

.select300-container--default .select300-results__option .select300-results__option .select300-results__group {
	padding-left: 0
}

.select300-container--default .select300-results__option .select300-results__option .select300-results__option {
	margin-left: -1em;
	padding-left: 2em
}

.select300-container--default .select300-results__option .select300-results__option .select300-results__option .select300-results__option {
	margin-left: -2em;
	padding-left: 3em
}

.select300-container--default .select300-results__option .select300-results__option .select300-results__option .select300-results__option .select300-results__option {
	margin-left: -3em;
	padding-left: 4em
}

.select300-container--default .select300-results__option .select300-results__option .select300-results__option .select300-results__option .select300-results__option .select300-results__option {
	margin-left: -4em;
	padding-left: 5em
}

.select300-container--default .select300-results__option .select300-results__option .select300-results__option .select300-results__option .select300-results__option .select300-results__option .select300-results__option {
	margin-left: -5em;
	padding-left: 6em
}

.select300-container--default .select300-results__option--highlighted[aria-selected] {
	background-color: #5897fb;
	color: white
}

.select300-container--default .select300-results__group {
	cursor: default;
	display: block;
	padding: 6px
}

.select300-container--classic .select300-selection--single {
	background-color: #f7f7f7;
	border: 1px solid #aaa;
	border-radius: 4px;
	outline: 0;
	background-image: -webkit-linear-gradient(top, #fff 50%, #eee 100%);
	background-image: -o-linear-gradient(top, #fff 50%, #eee 100%);
	background-image: linear-gradient(to bottom, #fff 50%, #eee 100%);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFFFFFFF', endColorstr='#FFEEEEEE', GradientType=0)
}

.select300-container--classic .select300-selection--single:focus {
	border: 1px solid #5897fb
}

.select300-container--classic .select300-selection--single .select300-selection__rendered {
	color: #444;
	line-height: 28px
}

.select300-container--classic .select300-selection--single .select300-selection__clear {
	cursor: pointer;
	float: right;
	font-weight: bold;
	margin-right: 10px
}

.select300-container--classic .select300-selection--single .select300-selection__placeholder {
	color: #999
}

.select300-container--classic .select300-selection--single .select300-selection__arrow {
	background-color: #ddd;
	border: none;
	border-left: 1px solid #aaa;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px;
	height: 26px;
	position: absolute;
	top: 1px;
	right: 1px;
	width: 20px;
	background-image: -webkit-linear-gradient(top, #eee 50%, #ccc 100%);
	background-image: -o-linear-gradient(top, #eee 50%, #ccc 100%);
	background-image: linear-gradient(to bottom, #eee 50%, #ccc 100%);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFEEEEEE', endColorstr='#FFCCCCCC', GradientType=0)
}

.select300-container--classic .select300-selection--single .select300-selection__arrow b {
	border-color: #888 transparent transparent transparent;
	border-style: solid;
	border-width: 5px 4px 0 4px;
	height: 0;
	left: 50%;
	margin-left: -4px;
	margin-top: -2px;
	position: absolute;
	top: 50%;
	width: 0
}

.select300-container--classic[dir="rtl"] .select300-selection--single .select300-selection__clear {
	float: left
}

.select300-container--classic[dir="rtl"] .select300-selection--single .select300-selection__arrow {
	border: none;
	border-right: 1px solid #aaa;
	border-radius: 0;
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	left: 1px;
	right: auto
}

.select300-container--classic.select300-container--open .select300-selection--single {
	border: 1px solid #5897fb
}

.select300-container--classic.select300-container--open .select300-selection--single .select300-selection__arrow {
	background: transparent;
	border: none
}

.select300-container--classic.select300-container--open .select300-selection--single .select300-selection__arrow b {
	border-color: transparent transparent #888 transparent;
	border-width: 0 4px 5px 4px
}

.select300-container--classic.select300-container--open.select300-container--above .select300-selection--single {
	border-top: none;
	border-top-left-radius: 0;
	border-top-right-radius: 0;
	background-image: -webkit-linear-gradient(top, #fff 0%, #eee 50%);
	background-image: -o-linear-gradient(top, #fff 0%, #eee 50%);
	background-image: linear-gradient(to bottom, #fff 0%, #eee 50%);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFFFFFFF', endColorstr='#FFEEEEEE', GradientType=0)
}

.select300-container--classic.select300-container--open.select300-container--below .select300-selection--single {
	border-bottom: none;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	background-image: -webkit-linear-gradient(top, #eee 50%, #fff 100%);
	background-image: -o-linear-gradient(top, #eee 50%, #fff 100%);
	background-image: linear-gradient(to bottom, #eee 50%, #fff 100%);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFEEEEEE', endColorstr='#FFFFFFFF', GradientType=0)
}

.select300-container--classic .select300-selection--multiple {
	background-color: white;
	border: 1px solid #aaa;
	border-radius: 4px;
	cursor: text;
	outline: 0
}

.select300-container--classic .select300-selection--multiple:focus {
	border: 1px solid #5897fb
}

.select300-container--classic .select300-selection--multiple .select300-selection__rendered {
	list-style: none;
	margin: 0;
	padding: 0 5px
}

.select300-container--classic .select300-selection--multiple .select300-selection__clear {
	display: none
}

.select300-container--classic .select300-selection--multiple .select300-selection__choice {
	background-color: #e4e4e4;
	border: 1px solid #aaa;
	border-radius: 4px;
	cursor: default;
	float: left;
	margin-right: 5px;
	margin-top: 5px;
	padding: 0 5px
}

.select300-container--classic .select300-selection--multiple .select300-selection__choice__remove {
	color: #888;
	cursor: pointer;
	display: inline-block;
	font-weight: bold;
	margin-right: 2px
}

.select300-container--classic .select300-selection--multiple .select300-selection__choice__remove:hover {
	color: #555
}

.select300-container--classic[dir="rtl"] .select300-selection--multiple .select300-selection__choice {
	float: right;
	margin-left: 5px;
	margin-right: auto
}

.select300-container--classic[dir="rtl"] .select300-selection--multiple .select300-selection__choice__remove {
	margin-left: 2px;
	margin-right: auto
}

.select300-container--classic.select300-container--open .select300-selection--multiple {
	border: 1px solid #5897fb
}

.select300-container--classic.select300-container--open.select300-container--above .select300-selection--multiple {
	border-top: none;
	border-top-left-radius: 0;
	border-top-right-radius: 0
}

.select300-container--classic.select300-container--open.select300-container--below .select300-selection--multiple {
	border-bottom: none;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0
}

.select300-container--classic .select300-search--dropdown .select300-search__field {
	border: 1px solid #aaa;
	outline: 0
}

.select300-container--classic .select300-search--inline .select300-search__field {
	outline: 0;
	box-shadow: none
}

.select300-container--classic .select300-dropdown {
	background-color: #fff;
	border: 1px solid transparent
}

.select300-container--classic .select300-dropdown--above {
	border-bottom: none
}

.select300-container--classic .select300-dropdown--below {
	border-top: none
}

.select300-container--classic .select300-results > .select300-results__options {
	max-height: 200px;
	overflow-y: auto
}

.select300-container--classic .select300-results__option[role=group] {
	padding: 0
}

.select300-container--classic .select300-results__option[aria-disabled=true] {
	color: grey
}

.select300-container--classic .select300-results__option--highlighted[aria-selected] {
	background-color: #3875d7;
	color: #fff
}

.select300-container--classic .select300-results__group {
	cursor: default;
	display: block;
	padding: 6px
}

.select300-container--classic.select300-container--open .select300-dropdown {
	border-color: #5897fb
}

.select300-container {
	display: block;
	width: 100% !important;
}

.select300-container--default .select300-selection--multiple .select300-selection__choice {
	border-radius: 20px;
	background: #E2E4E7;
	border: none;
	color: #32373C;
	padding-left: 8px;
	font-family: Helvetica Neue, serif;
	font-style: normal;
	font-weight: normal;
	font-size: 13px;
	line-height: 24px;
}

.select300-container--default .select300-selection--multiple .select300-selection__choice__remove {
	line-height: 1;
	width: 16px;
	height: 16px;
	float: right;
	display: block;
	border-radius: 50%;
	background-color: #555D66;
	color: #E2E4E7;
	text-align: center;
	margin: 4px 0px 4px 8px;
	font-size: 14px;
	box-sizing: border-box;
	padding-top: 0;
	padding-left: 0;
}

.select300-container--default .select300-selection--multiple .select300-selection__choice__remove:hover {
	background-color: #333;
	color: #E2E4E7;
}

.monsterinsights-widget-theme-preview {
	background: #F0F2F4;
	border-radius: 5px;
	padding: 8px 8px 8px 18px;
	display: flex;
	font-family: Helvetica Neue, serif;
	font-style: normal;
	font-weight: normal;
	font-size: 14px;
	line-height: 1;
	color: #32373C;
	align-items: center;
	justify-content: space-between;
}

.monsterinsights-widget-theme-preview-icon,
.monsterinsights-products-theme-preview-icon {
	width: 74px;
	height: 46px;
	background-image: url(data:image/png;base64, );
	background-repeat: no-repeat;
	background-position: 0 0;
	background-size: 392px;
	display: inline-block;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-beta {
	background-position-x: -212px;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-charlie {
	background-position-x: -106px;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-delta {
	height: 43px;
	background-position: -318px 0;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-echo {
	height: 76px;
	background-position: 0 -73px;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-foxtrot {
	background-position: -106px -90px;
	height: 41px;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-golf {
	background-position: -212px -83px;
	height: 56px;
}

.monsterinsights-widget-theme-preview-icon.monsterinsights-widget-theme-preview-icon-hotel {
	height: 50px;
	background-position: -318px -86px;
}

.monsterinsights-products-theme-preview-icon {
	background-image: url('data:image/png;base64, ');
	width: 74px;
	height: 39px;
	background-size: 188px;
}

.monsterinsights-products-theme-preview-icon.monsterinsights-products-theme-preview-icon-alpha {
	background-position: 0 0;
}

.monsterinsights-products-theme-preview-icon.monsterinsights-products-theme-preview-icon-beta {
	background-position: -114px 0;
	height: 65px;
}

.monsterinsights-products-theme-preview-icon.monsterinsights-products-theme-preview-icon-charlie {
	background-position: 0 -102px;
	height: 50px;
}

.monsterinsights-products-theme-preview-icon.monsterinsights-products-theme-preview-icon-delta {
	background-position: -114px -102px;
	height: 78px;
}

.monsterinsights-pro-pill {
	font-style: normal;
	font-weight: bold;
	font-size: 11px;
	background: #1EC185;
	border-radius: 5px;
	color: #fff;
	padding: 3px 8px;
	margin-left: 8px;
}

.select300-container--disabled {
	margin-top: 10px;
	opacity: 0.6;
}
