.monsterinsights-wpconsent-notice-box{display:flex;border:1px solid #e0e0e0;border-left:4px solid #2e7fbe;border-radius:4px;background-color:#fff;position:relative;padding:0}[dir=rtl] .monsterinsights-wpconsent-notice-box{border-left:none;border-right:4px solid #2e7fbe}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-sidebar{padding:20px 5px 20px 20px}[dir=rtl] .monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-sidebar{padding:20px 20px 20px 5px}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-icon img{width:72px;height:auto}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-close{position:absolute;top:1px;right:4px;border:none;background:transparent;font-size:22px;cursor:pointer;padding:0 5px}[dir=rtl] .monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-close{right:auto;left:4px}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-content{flex:1;position:relative;padding:20px}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-content h3{margin:0 0 9px;font-size:18px;font-weight:600}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-content p{margin:0 0 15px;color:#555;font-size:14px;padding:0}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-buttons{display:flex;gap:10px}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-buttons a{padding:8px 15px;border-radius:4px;font-size:14px;text-decoration:none;border:1px solid #2e7fbe}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-btn-primary{background-color:#2e7fbe;color:#fff}.monsterinsights-wpconsent-notice-box .monsterinsights-wpconsent-btn-secondary{background-color:transparent;color:#2e7fbe}
