<?php
/**
 * Classic field template.
 *
 * This template can be overridden by copying it to yourtheme/wpforms/emails/classic-field.php.
 *
 * @since 1.8.5
 */

?>

<tr>
	<td class="field-name"><strong>{field_name}</strong></td>
</tr>
<tr class="field-{field_type}">
	<td class="field-value">{field_value}</td>
</tr>
