#ez-toc-sticky-container {
    background: transparent;
    border: 1px solid #AAAAAA;
    border-radius: 4px;
    /* -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05); */
    display: table;
    margin-bottom: 1em;
    padding: 10px;
    position: relative;
    width: auto;
}

div.ez-toc-sticky-widget-container {
    padding: 0;
    position: relative;
}

#ez-toc-sticky-container.ez-toc-sticky-light-blue {
    background: #EDF6FF;
}

#ez-toc-sticky-container.ez-toc-sticky-white {
    background: #FFFFFF;
}

#ez-toc-sticky-container.ez-toc-sticky-black {
    background: #000000;
}

#ez-toc-sticky-container.ez-toc-sticky-transparent {
    background: none transparent;
}

div.ez-toc-sticky-widget-container ul {
    display: block;
}

div.ez-toc-sticky-widget-container li {
    border: none;
    padding: 0;
}

div.ez-toc-sticky-widget-container ul.ez-toc-sticky-list {
    padding: 10px;
}

#ez-toc-sticky-container ul ul,
.ez-toc div.ez-toc-sticky-widget-container ul ul {
    margin-left: 1.5em;
}

#ez-toc-sticky-container ul,
#ez-toc-sticky-container li {
    margin: 0;
    padding: 0;
}

#ez-toc-sticky-container ul,
#ez-toc-sticky-container li,
#ez-toc-sticky-container ul li,
div.ez-toc-sticky-widget-container,
div.ez-toc-sticky-widget-container li {
    background: none;
    list-style: none none;
    line-height: 1.6;
    margin: 0;
    overflow: hidden;
    z-index: 1;
}

#ez-toc-sticky-container p.ez-toc-sticky-title {
    text-align: left;
    line-height: 1.45;
    margin: 0;
    padding: 0;
}

.ez-toc-sticky-title-container {
    display: table;
    width: 100%;
}

.ez-toc-sticky-title,
.ez-toc-sticky-title-toggle {
    display: table-cell;
    text-align: left;
    vertical-align: middle;
}

#ez-toc-sticky-container.ez-toc-sticky-black p.ez-toc-sticky-title {
    color: #FFF;
}

#ez-toc-sticky-container div.ez-toc-sticky-title-container + ul.ez-toc-sticky-list {
    margin-top: 1em;
}

.ez-toc-sticky-wrap-left {
    float: left;
    margin-right: 10px;
}

.ez-toc-sticky-wrap-right {
    float: right;
    margin-left: 10px;
}

.ez-toc-sticky-wrap-center {
    margin: 0 auto;
}

#ez-toc-sticky-container a {
    color: #444444;
    box-shadow: none;
    text-decoration: none;
    text-shadow: none;
    display: inline-flex;
    align-items: stretch;
    flex-wrap: nowrap;
}

#ez-toc-sticky-container a:visited {
    color: #9f9f9f;
}

#ez-toc-sticky-container a:hover {
    text-decoration: underline;
}

#ez-toc-sticky-container.ez-toc-sticky-black a {
    color: #FFF;
}

#ez-toc-sticky-container.ez-toc-sticky-black a:visited {
    color: #FFF;
}

#ez-toc-sticky-container a.ez-toc-sticky-toggle {
    color: #444444;
}

.ez-toc-sticky-widget-container ul.ez-toc-sticky-list li::before {
    content: ' ';
    position: absolute;
    left: 0;
    right: 0;
    height: 30px;
    line-height: 30px;
    z-index: -1;
}

.ez-toc-sticky-widget-container ul.ez-toc-sticky-list li.active {
    background-color: #EDEDED;
}

.ez-toc-sticky-widget-container li.active > a {
    font-weight: 900;
}

.ez-toc-sticky-btn {
    display: inline-block;
    padding: 6px 12px;
    margin-bottom: 0;
    font-size: 14px;
    font-weight: normal;
    line-height: 1.428571429;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 4px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    -o-user-select: none;
    user-select: none
}

.ez-toc-sticky-btn:focus {
    outline: thin dotted #333;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

.ez-toc-sticky-btn:hover, .ez-toc-sticky-btn:focus {
    color: #333;
    text-decoration: none
}

.ez-toc-sticky-btn:active, .ez-toc-sticky-btn.active {
    background-image: none;
    outline: 0;
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125)
}

.ez-toc-sticky-btn-default {
    color: #333;
    background-color: #fff;
    border-color: #ccc
}

.ez-toc-sticky-btn-default:hover, .ez-toc-sticky-btn-default:focus, .ez-toc-sticky-btn-default:active, .ez-toc-sticky-btn-default.active {
    color: #333;
    background-color: #ebebeb;
    border-color: #adadad
}

.ez-toc-sticky-btn-default:active, .ez-toc-sticky-btn-default.active {
    background-image: none
}

.ez-toc-sticky-btn-sm, .ez-toc-sticky-btn-xs {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px
}

.ez-toc-sticky-btn-xs {
    padding: 1px 5px
}

.ez-toc-sticky-btn-default {
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075)
}

.ez-toc-sticky-btn-default:active {
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125)
}

.ez-toc-sticky-btn:active, .btn.active {
    background-image: none
}

.ez-toc-sticky-btn-default {
    text-shadow: 0 1px 0 #fff;
    background-image: -webkit-gradient(linear, left 0, left 100%, from(#fff), to(#e0e0e0));
    background-image: -webkit-linear-gradient(top, #fff 0, #e0e0e0 100%);
    background-image: -moz-linear-gradient(top, #fff 0, #e0e0e0 100%);
    background-image: linear-gradient(to bottom, #fff 0, #e0e0e0 100%);
    background-repeat: repeat-x;
    border-color: #dbdbdb;
    border-color: #ccc;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffe0e0e0', GradientType=0);
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false)
}

.ez-toc-sticky-btn-default:hover, .ez-toc-sticky-btn-default:focus {
    background-color: #e0e0e0;
    background-position: 0 -15px
}

.ez-toc-sticky-btn-default:active, .ez-toc-sticky-btn-default.active {
    background-color: #e0e0e0;
    border-color: #dbdbdb
}

.ez-toc-sticky-pull-right {
    float: right !important;
    margin-left: 10px;
}

.ez-toc-sticky-glyphicon {
    position: relative;
    top: 1px;
    display: inline-block;
    font-family: 'Glyphicons Halflings';
    -webkit-font-smoothing: antialiased;
    font-style: normal;
    font-weight: normal;
    line-height: 1;
    -moz-osx-font-smoothing: grayscale
}

.ez-toc-sticky-glyphicon:empty {
    width: 1em
}

.ez-toc-sticky-toggle i.ez-toc-sticky-glyphicon {
    font-size: 16px;
    margin-left: 2px;
}

#ez-toc-sticky-container input {
    position: absolute;
    left: -999em;
}

#ez-toc-sticky-container input[type="checkbox"]:checked + nav {
    opacity: 0;
    max-height: 0;
    border: none;
    display: none;
}

#ez-toc-sticky-container label {
    float: right;
    position: relative;
    left: 10px;
    font-size: 16px;
    background: #f9efef;
    padding: 0px 4px 0px 5px;
    border: 1px solid #999191;
    border-radius: 5px;
    cursor: pointer;
}

div#ez-toc-sticky-container p.ez-toc-sticky-title {
    display: contents;
}

div#ez-toc-sticky-container {
    padding-right: 20px;
}

label.cssicon .ez-toc-sticky-glyphicon:empty {
    font-size: 16px;
    margin-left: 2px;
}

label.cssiconcheckbox {
    display: none;
}

.ez-toc-sticky-widget-container ul li a {
    padding-left: 10px;
}

.ez-toc-sticky-widget-container ul.ez-toc-sticky-list li.active {
    height: auto !important;
}