<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * Indicates the brand for a co-branded card.
 */
class CardCoBrand
{
    public const UNKNOWN = 'UNKNOWN';
    public const AFTERPAY = 'AFTERPAY';
    public const CLEARPAY = 'CLEARPAY';
}
