.monsterinsights-ai-charlie__toggle {
  position: fixed;
  bottom: 20px;
  right: 20px;
  z-index: 999999;
  display: block;
  padding: 0;
  border: none;
  background: none;
  cursor: pointer;
  line-height: 0;
  transition: transform 0.3s ease-out;
}
.monsterinsights-ai-charlie__toggle:hover {
  transform: scale(1.1) translateY(-8px);
}
.monsterinsights-ai-charlie__toggle:hover .monsterinsights-ai-charlie__toggle-glow {
  opacity: 0.9;
  transform: translate(-50%, 0) scale(1.15);
}
.monsterinsights-ai-charlie__toggle-img {
  display: block;
  width: 104px;
  height: auto;
  position: relative;
  z-index: 1;
}
.monsterinsights-ai-charlie__toggle-glow {
  position: absolute;
  bottom: -6px;
  left: 50%;
  transform: translate(-50%, 0) scale(1);
  width: 101px;
  height: 64px;
  border-radius: 100px;
  background: linear-gradient(95.62deg, rgb(105, 61, 201) 4.02%, rgb(34, 139, 238) 75.22%);
  filter: blur(15px);
  opacity: 0.5;
  pointer-events: none;
  transition: opacity 0.3s ease-out, transform 0.3s ease-out;
  z-index: 0;
}
.monsterinsights-ai-charlie__toggle-star {
  position: absolute;
  left: 50%;
  top: 50%;
  margin-left: -8px;
  margin-top: -8px;
  pointer-events: none;
  opacity: 0;
  transform: scale(0) translate(0, 0);
  z-index: 2;
}
.monsterinsights-ai-charlie__toggle-star.is-active {
  animation: mi-charlie-star-burst 0.8s var(--star-delay, 0s) ease-out forwards;
}
.monsterinsights-ai-charlie__popup {
  position: fixed;
  right: 0;
  bottom: 0;
  width: 350px;
  z-index: 999999;
  background: #fff;
  border-radius: 8px;
  box-shadow: -4px 0 24px rgba(0, 0, 0, 0.1);
  display: flex;
  flex-direction: column;
  overflow: hidden;
  height: 100%;
  max-height: 752px;
}
.monsterinsights-ai-charlie__popup.is-expanded {
  width: 700px;
  max-height: 100%;
  transition: width 0.2s ease, max-height 0.2s ease;
}
.monsterinsights-ai-charlie__popup {
  transition: width 0.2s ease, max-height 0.2s ease;
}
.monsterinsights-ai-charlie__popup-header {
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 12px 20px;
  flex-shrink: 0;
  border-bottom: 1px solid #d6e2ed;
  min-height: 57px;
  box-sizing: border-box;
}
.monsterinsights-ai-charlie__popup-header-left {
  display: flex;
  align-items: center;
  gap: 12px;
}
.monsterinsights-ai-charlie__popup-header-right {
  display: flex;
  align-items: center;
  gap: 16px;
}
.monsterinsights-ai-charlie__popup-header-btn {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0;
  border: none;
  background: none;
  cursor: pointer;
  line-height: 0;
}
.monsterinsights-ai-charlie__popup-header-logo {
  width: 32px;
  height: 32px;
  display: block;
}
.monsterinsights-ai-charlie__popup-menu-wrapper {
  position: relative;
}
.monsterinsights-ai-charlie__popup-menu {
  position: absolute;
  top: calc(100% + 16px);
  left: -8px;
  z-index: 20;
  width: 232px;
  padding: 12px;
  background: #fff;
  border-radius: 8px;
  box-shadow: 0 7px 29px rgba(100, 100, 111, 0.2);
  display: flex;
  flex-direction: column;
}
.monsterinsights-ai-charlie__popup-menu-item {
  display: flex;
  align-items: center;
  gap: 12px;
  padding: 10px 12px;
  border: none;
  border-radius: 8px;
  background: none;
  cursor: pointer;
  width: 100%;
  text-align: left;
  font-size: 16px;
  line-height: 24px;
  color: #2F363B;
  white-space: nowrap;
}
.monsterinsights-ai-charlie__popup-menu-item:hover {
  background: #F2F6FF;
}
.monsterinsights-ai-charlie__popup-menu-item svg {
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__popup-header-back {
  display: flex;
  align-items: center;
  gap: 8px;
  padding: 0;
  border: none;
  background: none;
  cursor: pointer;
}
.monsterinsights-ai-charlie__popup-header-back .mi-icon {
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__popup-header-view-title {
  font-size: 16px;
  line-height: 24px;
  font-weight: 500;
  color: #2F363B;
  letter-spacing: -0.32px;
  white-space: nowrap;
}
.monsterinsights-ai-charlie__popup-save-btn {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 2px 8px;
  border-radius: 4px;
  border: none;
  background: transparent;
  cursor: pointer;
  font-size: 16px;
  line-height: 24px;
  color: #2F363B;
  min-width: 48px;
  min-height: 28px;
}
.monsterinsights-ai-charlie__popup-save-btn:hover, .monsterinsights-ai-charlie__popup-save-btn:focus {
  background-color: #F2F6FF;
}
.monsterinsights-ai-charlie__popup-save-btn:disabled {
  cursor: default;
  opacity: 1;
}
.monsterinsights-ai-charlie__popup-save-spinner {
  animation: mi-charlie-save-spin 0.8s linear infinite;
}
.monsterinsights-ai-charlie__popup-toast {
  position: absolute;
  top: 68px;
  left: 50%;
  transform: translateX(-50%);
  z-index: 10;
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 8px;
  padding: 10px 16px;
  border-radius: 4px;
  background: #26ab66;
  color: #fff;
  font-size: 16px;
  line-height: 24px;
  white-space: nowrap;
}
.monsterinsights-ai-charlie__popup-body {
  flex: 1;
  overflow-y: auto;
  overscroll-behavior: contain;
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 0 20px;
}
.monsterinsights-ai-charlie__popup-mascot {
  margin-top: 50px;
  display: flex;
  justify-content: center;
}
.monsterinsights-ai-charlie__popup-mascot img {
  max-width: 144px;
  height: auto;
  display: block;
}
.monsterinsights-ai-charlie__popup-title {
  margin: 16px 0 0;
  padding: 0;
  font-size: 24px;
  line-height: 28px;
  font-weight: 500;
  color: #509fe2;
  text-align: center;
}
.monsterinsights-ai-charlie__not-connected {
  padding: 0 24px 24px;
  text-align: center;
}
.monsterinsights-ai-charlie__not-connected-title {
  margin: 16px 0 8px;
  padding: 0;
  font-size: 18px;
  line-height: 24px;
  font-weight: 500;
  color: #509fe2;
}
.monsterinsights-ai-charlie__not-connected-text {
  margin: 0 0 20px;
  font-size: 14px;
  line-height: 20px;
  color: #2F363B;
}
.monsterinsights-ai-charlie__not-connected-btn {
  display: inline-block;
  padding: 10px 20px;
  background: #509fe2;
  color: #fff;
  border-radius: 6px;
  font-size: 14px;
  font-weight: 500;
  text-decoration: none;
  transition: opacity 0.2s;
}
.monsterinsights-ai-charlie__not-connected-btn:hover {
  opacity: 0.85;
  color: #fff;
}
.monsterinsights-ai-charlie__popup-suggestions {
  width: 100%;
  margin-top: 32px;
  display: flex;
  flex-direction: column;
  gap: 12px;
}
.monsterinsights-ai-charlie__popup-suggestion {
  display: flex;
  align-items: flex-start;
  gap: 12px;
  padding: 0 0 12px;
  border: none;
  border-bottom: 1px dashed #D6DEEF;
  background: none;
  cursor: pointer;
  text-align: left;
  width: 100%;
}
.monsterinsights-ai-charlie__popup-suggestion:last-child {
  border-bottom: none;
}
.monsterinsights-ai-charlie__popup-suggestion svg {
  margin-top: 2px;
}
.monsterinsights-ai-charlie__popup-suggestion:hover .monsterinsights-ai-charlie__popup-suggestion-text {
  color: #509fe2;
}
.monsterinsights-ai-charlie__popup-suggestion:hover svg path {
  stroke: #509fe2;
}
.monsterinsights-ai-charlie__popup-suggestion-text {
  flex: 1;
  font-size: 14px;
  line-height: 20px;
  font-weight: 500;
  color: #393f4c;
}
.monsterinsights-ai-charlie__jump-to-latest {
  position: absolute;
  bottom: 86px;
  left: 50%;
  transform: translateX(-50%);
  z-index: 10;
  display: inline-flex;
  align-items: center;
  gap: 6px;
  padding: 10px 18px;
  border: none;
  border-radius: 999px;
  background: #2F363B;
  color: #fff;
  font-size: 14px;
  line-height: 22px;
  font-weight: 500;
  white-space: nowrap;
  cursor: pointer;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.18);
  transition: box-shadow 0.2s ease, transform 0.15s ease;
}
.monsterinsights-ai-charlie__jump-to-latest:hover {
  box-shadow: 0 4px 16px rgba(80, 159, 226, 0.55);
}
.monsterinsights-ai-charlie__jump-to-latest:active {
  transform: translateX(-50%) translateY(1px);
}
.monsterinsights-ai-charlie__jump-to-latest svg {
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__popup-footer {
  padding: 16px 20px;
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__popup-input {
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 11px 16px;
  border: 1px solid #d6e2ed;
  border-radius: 8px;
  background: transparent;
}
.monsterinsights-ai-charlie__popup-input:focus-within {
  border-color: #777;
}
.monsterinsights-ai-charlie__popup-input-send {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0;
  border: none;
  background: none;
  cursor: pointer;
  flex-shrink: 0;
  margin-left: 8px;
  line-height: 0;
}
.monsterinsights-ai-charlie__chat-messages {
  width: 100%;
  display: flex;
  flex-direction: column;
  gap: 24px;
  padding: 20px 0;
}
.monsterinsights-ai-charlie__chat-spacer {
  flex-shrink: 0;
  min-height: 400px;
  pointer-events: none;
}
.monsterinsights-ai-charlie__upsell {
  position: absolute;
  left: 50%;
  bottom: 88px;
  transform: translateX(-50%);
  z-index: 11;
  width: 75%;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  gap: 16px;
  padding: 32px 20px;
  border: 1px solid #d6e2ed;
  border-radius: 8px;
  background: #fff;
  box-shadow: 10px 0 100px 50px rgb(255, 255, 255);
}
.monsterinsights-ai-charlie__upsell-dismiss {
  position: absolute;
  top: 10px;
  right: 10px;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 24px;
  height: 24px;
  padding: 0;
  border: none;
  border-radius: 4px;
  background: transparent;
  color: #2F363B;
  cursor: pointer;
  opacity: 0.7;
  transition: opacity 0.15s ease, background 0.15s ease;
}
.monsterinsights-ai-charlie__upsell-dismiss:hover {
  opacity: 1;
  background: #F2F6FF;
}
.monsterinsights-ai-charlie__upsell-icon {
  display: block;
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__upsell-title {
  margin: 0;
  padding: 0;
  font-size: 20px;
  line-height: 24px;
  font-weight: 700;
  letter-spacing: -0.2px;
  color: #393f4c;
  text-align: center;
}
.monsterinsights-ai-charlie__upsell-bullets {
  margin: 0;
  padding: 0;
  list-style: none;
  display: flex;
  flex-direction: column;
  gap: 8px;
}
.monsterinsights-ai-charlie__upsell-bullets li {
  display: flex;
  align-items: center;
  gap: 8px;
  font-size: 14px;
  line-height: 20px;
  color: #393f4c;
}
.monsterinsights-ai-charlie__upsell-bullet-icon {
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__upsell-cta-group {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 12px;
  width: 100%;
}
.monsterinsights-ai-charlie__upsell-cta {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  gap: 8px;
  padding: 12px 20px;
  border: none;
  border-radius: 4px;
  outline: none;
  box-shadow: none;
  background: #228BEE;
  color: #fff;
  font-size: 14px;
  line-height: 24px;
  font-weight: 700;
  text-decoration: none;
  transition: background 0.15s ease;
}
.monsterinsights-ai-charlie__upsell-cta:visited {
  background: #228BEE;
  color: #fff;
}
.monsterinsights-ai-charlie__upsell-cta:hover, .monsterinsights-ai-charlie__upsell-cta:visited:hover {
  background: rgb(16.5142857143, 118.5142857143, 214.6857142857);
  color: #fff;
}
.monsterinsights-ai-charlie__upsell-caption {
  margin: 0;
  font-size: 14px;
  line-height: 24px;
  letter-spacing: -0.14px;
  color: #2F363B;
  text-align: center;
}
.monsterinsights-ai-charlie__popup-input.is-disabled {
  opacity: 0.55;
  pointer-events: none;
}
.monsterinsights-ai-charlie__msg-user {
  display: flex;
  justify-content: flex-end;
  width: 100%;
}
.monsterinsights-ai-charlie__msg-user-bubble {
  background: #F2F6FF;
  border-radius: 8px;
  padding: 12px;
  font-size: 14px;
  line-height: 20px;
  color: #2F363B;
  max-width: 214px;
  word-wrap: break-word;
}
.monsterinsights-ai-charlie__msg-ai {
  display: flex;
  flex-direction: column;
  gap: 16px;
  width: 100%;
}
.monsterinsights-ai-charlie__msg-ai-text {
  font-size: 14px;
  line-height: 20px;
  color: #2F363B;
  word-wrap: break-word;
}
.monsterinsights-ai-charlie__msg-ai-text h2,
.monsterinsights-ai-charlie__msg-ai-text h3,
.monsterinsights-ai-charlie__msg-ai-text h4 {
  margin: 16px 0 8px;
  font-weight: 600;
  color: #393f4c;
}
.monsterinsights-ai-charlie__msg-ai-text h2 {
  font-size: 16px;
  line-height: 22px;
}
.monsterinsights-ai-charlie__msg-ai-text h3 {
  font-size: 15px;
  line-height: 20px;
}
.monsterinsights-ai-charlie__msg-ai-text h4 {
  font-size: 14px;
  line-height: 20px;
}
.monsterinsights-ai-charlie__msg-ai-text h2:first-child,
.monsterinsights-ai-charlie__msg-ai-text h3:first-child,
.monsterinsights-ai-charlie__msg-ai-text h4:first-child {
  margin-top: 0;
}
.monsterinsights-ai-charlie__msg-ai-text p {
  margin: 0 0 8px;
  font-size: inherit;
  line-height: inherit;
}
.monsterinsights-ai-charlie__msg-ai-text p:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text strong {
  font-weight: 600;
  color: #393f4c;
}
.monsterinsights-ai-charlie__msg-ai-text em {
  font-style: italic;
}
.monsterinsights-ai-charlie__msg-ai-text a {
  color: #509fe2;
  text-decoration: underline;
}
.monsterinsights-ai-charlie__msg-ai-text a:hover {
  text-decoration: none;
}
.monsterinsights-ai-charlie__msg-ai-text ul {
  list-style: disc outside;
  margin: 8px 0;
  padding-left: 16px;
}
.monsterinsights-ai-charlie__msg-ai-text ul:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text ol {
  list-style: decimal outside;
  margin: 8px 0;
  padding-left: 16px;
}
.monsterinsights-ai-charlie__msg-ai-text ol:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text li {
  margin-bottom: 2px;
  padding-left: 2px;
  font-size: inherit;
  line-height: inherit;
}
.monsterinsights-ai-charlie__msg-ai-text li::marker {
  color: #2F363B;
}
.monsterinsights-ai-charlie__msg-ai-text li:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text code {
  font-family: monospace;
  font-size: 13px;
  background: rgba(0, 0, 0, 0.06);
  padding: 2px 4px;
  border-radius: 3px;
}
.monsterinsights-ai-charlie__msg-ai-text pre {
  margin: 8px 0;
  padding: 12px;
  background: #1e1e2e;
  border-radius: 6px;
  overflow-x: auto;
}
.monsterinsights-ai-charlie__msg-ai-text pre:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text pre code {
  background: none;
  padding: 0;
  border-radius: 0;
  color: #cdd6f4;
  font-size: 12px;
  line-height: 18px;
}
.monsterinsights-ai-charlie__msg-ai-text table {
  width: 100%;
  border-collapse: collapse;
  margin: 8px 0;
  font-size: 13px;
}
.monsterinsights-ai-charlie__msg-ai-text table:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text th,
.monsterinsights-ai-charlie__msg-ai-text td {
  padding: 6px 8px;
  text-align: left;
  border-bottom: 1px solid #d6e2ed;
}
.monsterinsights-ai-charlie__msg-ai-text th {
  font-weight: 600;
  color: #393f4c;
}
.monsterinsights-ai-charlie__msg-ai-text blockquote {
  margin: 8px 0;
  padding: 8px 12px;
  border-left: 3px solid #d6e2ed;
  color: #2F363B;
}
.monsterinsights-ai-charlie__msg-ai-text blockquote:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-text hr {
  border: none;
  border-top: 1px solid #d6e2ed;
  margin: 12px 0;
}
.monsterinsights-ai-charlie__msg-ai-table-wrap {
  max-width: 100%;
  overflow-x: auto;
  margin: 8px 0;
}
.monsterinsights-ai-charlie__msg-ai-table-wrap:last-child {
  margin-bottom: 0;
}
.monsterinsights-ai-charlie__msg-ai-table-wrap table {
  margin: 0;
}
.monsterinsights-ai-charlie__msg-ai-actions {
  display: flex;
  align-items: center;
  gap: 16px;
}
.monsterinsights-ai-charlie__msg-ai-action-btn {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0;
  border: none;
  background: none;
  cursor: pointer;
  line-height: 0;
}
.monsterinsights-ai-charlie__msg-ai-action-btn:hover svg path, .monsterinsights-ai-charlie__msg-ai-action-btn.is-active svg path {
  stroke: #2F363B;
}
.monsterinsights-ai-charlie__msg-ai-action-btn:disabled {
  opacity: 0.4;
  cursor: not-allowed;
}
.monsterinsights-ai-charlie__msg-ai-feedback-thanks {
  margin-top: 8px;
  font-size: 13px;
  color: #2F363B;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment {
  display: flex;
  gap: 8px;
  margin-top: 8px;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment-input {
  flex: 1;
  padding: 8px 10px;
  border: 1px solid #d0d5dd;
  border-radius: 8px;
  font-size: 13px;
  font-family: inherit;
  resize: none;
  outline: none;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment-input:focus {
  border-color: #228bee;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment-input::placeholder {
  color: #98a2b3;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment-btn {
  align-self: flex-end;
  padding: 6px 14px;
  border: none;
  border-radius: 8px;
  background: #393f4c;
  color: #fff;
  font-size: 13px;
  font-family: inherit;
  cursor: pointer;
  white-space: nowrap;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment-btn:hover {
  background: #2f363b;
}
.monsterinsights-ai-charlie__msg-ai-feedback-comment-btn:disabled {
  opacity: 0.4;
  cursor: not-allowed;
}
.monsterinsights-ai-charlie__msg-ai-insights {
  display: flex;
  flex-direction: column;
  gap: 16px;
  width: 100%;
  margin-top: 20px;
}
.monsterinsights-ai-charlie__msg-ai-insights-header {
  display: flex;
  align-items: center;
  gap: 8px;
  height: 16px;
}
.monsterinsights-ai-charlie__msg-ai-insights-title {
  font-size: 14px;
  line-height: 20px;
  font-weight: 700;
  color: #393f4c;
}
.monsterinsights-ai-charlie__msg-ai-insights-list {
  display: flex;
  flex-direction: column;
  gap: 16px;
}
.monsterinsights-ai-charlie__msg-ai-insight-item {
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 8px;
  min-height: 32px;
}
.monsterinsights-ai-charlie__msg-ai-insight-item.has-border {
  padding-bottom: 16px;
  border-bottom: 1px dashed #D6DEEF;
}
.monsterinsights-ai-charlie__msg-ai-insight-label {
  flex: 1;
  font-size: 14px;
  line-height: 20px;
  font-weight: 500;
  color: #2F363B;
}
.monsterinsights-ai-charlie__msg-ai-insight-btn {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 8px;
  border: none;
  border-radius: 4px;
  background: #228BEE;
  color: #fff;
  font-size: 14px;
  line-height: 1.4;
  font-weight: 500;
  cursor: pointer;
  white-space: nowrap;
  flex-shrink: 0;
}
.monsterinsights-ai-charlie__msg-ai-insight-btn:hover {
  background: #3a93dd;
}
.monsterinsights-ai-charlie__msg-ai-typing {
  display: flex;
  align-items: center;
  gap: 4px;
  padding: 8px 0;
}
.monsterinsights-ai-charlie__msg-ai-typing span {
  display: block;
  width: 8px;
  height: 8px;
  border-radius: 50%;
  background: #B6BDC2;
  animation: mi-charlie-typing 1.4s infinite ease-in-out both;
}
.monsterinsights-ai-charlie__msg-ai-typing span:nth-child(1) {
  animation-delay: -0.32s;
}
.monsterinsights-ai-charlie__msg-ai-typing span:nth-child(2) {
  animation-delay: -0.16s;
}
.monsterinsights-ai-charlie__msg-ai-status {
  width: auto !important;
  height: auto !important;
  border-radius: 0 !important;
  background: none !important;
  animation: none !important;
  font-size: 12px;
  color: #8C9196;
  margin-left: 4px;
}
.monsterinsights-ai-charlie__conv-list {
  width: 100%;
  padding: 20px 0;
  display: flex;
  flex-direction: column;
  gap: 32px;
}
.monsterinsights-ai-charlie__conv-group {
  display: flex;
  flex-direction: column;
  align-items: center;
  width: 100%;
}
.monsterinsights-ai-charlie__conv-date {
  display: flex;
  justify-content: center;
  margin-bottom: 12px;
}
.monsterinsights-ai-charlie__conv-date span {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  padding: 4px 8px;
  border-radius: 4px;
  background: #eff2f5;
  font-size: 12px;
  line-height: 16px;
  color: #393f4c;
  text-align: center;
  white-space: nowrap;
}
.monsterinsights-ai-charlie__conv-items {
  width: 100%;
  display: flex;
  flex-direction: column;
  gap: 12px;
}
.monsterinsights-ai-charlie__conv-item {
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
}
.monsterinsights-ai-charlie__conv-item.has-border {
  padding-bottom: 12px;
  border-bottom: 1px dashed #D6DEEF;
}
.monsterinsights-ai-charlie__conv-item-text {
  flex: 1;
  display: flex;
  align-items: center;
  min-height: 40px;
  padding: 0;
  border: none;
  background: none;
  cursor: pointer;
  text-align: left;
  font-size: 14px;
  line-height: 20px;
  color: #393f4c;
  overflow: hidden;
}
.monsterinsights-ai-charlie__conv-item-actions {
  position: relative;
  flex-shrink: 0;
  margin-left: 8px;
}
.monsterinsights-ai-charlie__conv-item-more {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0;
  border: none;
  border-radius: 4px;
  background: none;
  cursor: pointer;
  width: 24px;
  height: 24px;
}
.monsterinsights-ai-charlie__conv-item-more:hover, .monsterinsights-ai-charlie__conv-item-more.is-active {
  background: #e8edfa;
}
.monsterinsights-ai-charlie__conv-item-more .mi-icon {
  width: 24px;
  height: 24px;
}
.monsterinsights-ai-charlie__conv-item-menu {
  position: absolute;
  top: 100%;
  right: 0;
  z-index: 10;
  margin-top: 4px;
  background: #fff;
  border-radius: 6px;
  box-shadow: 0 1px 4px rgba(57, 63, 76, 0.12);
  overflow: hidden;
}
.monsterinsights-ai-charlie__conv-item-menu button {
  display: flex;
  align-items: center;
  gap: 6px;
  width: 100%;
  padding: 8px 12px;
  border: none;
  background: none;
  cursor: pointer;
  white-space: nowrap;
}
.monsterinsights-ai-charlie__conv-item-menu button span {
  font-size: 14px;
  line-height: 16px;
  font-weight: 500;
  color: #393f4c;
  letter-spacing: -0.5px;
}
.monsterinsights-ai-charlie__conv-item-menu button:hover {
  background: #f5f6f8;
}
.monsterinsights-ai-charlie__conv-item-menu button:disabled {
  opacity: 0.5;
  cursor: not-allowed;
}
.monsterinsights-ai-charlie__conv-item-menu button:disabled:hover {
  background: none;
}
.monsterinsights-ai-charlie__conv-item-menu button:last-child span {
  color: #eb5757;
}
.monsterinsights-ai-charlie__conv-item-menu button:last-child:hover {
  background: #fef2f2;
}
.monsterinsights-ai-charlie__conv-item-pin-icon {
  flex-shrink: 0;
  margin-right: 4px;
}
.monsterinsights-ai-charlie__conv-item-trash-icon {
  filter: brightness(0) saturate(100%) invert(44%) sepia(63%) saturate(2397%) hue-rotate(335deg) brightness(96%) contrast(92%);
}
.monsterinsights-ai-charlie__conv-load-more-wrap {
  padding: 12px 20px 4px;
  display: flex;
  justify-content: center;
}
.monsterinsights-ai-charlie__conv-load-more {
  background: none;
  border: 1px solid #d6e2ed;
  border-radius: 6px;
  padding: 7px 16px;
  font-size: 13px;
  font-weight: 500;
  color: #393f4c;
  cursor: pointer;
  transition: border-color 0.2s, color 0.2s;
}
.monsterinsights-ai-charlie__conv-load-more:hover:not(:disabled) {
  border-color: #509fe2;
  color: #509fe2;
}
.monsterinsights-ai-charlie__conv-load-more:disabled {
  opacity: 0.5;
  cursor: default;
}

@keyframes mi-charlie-star-burst {
  0% {
    opacity: 0;
    transform: scale(0) translate(0, 0);
  }
  30% {
    opacity: 1;
    transform: scale(1) translate(calc(var(--star-x, 0px) * 0.5), calc(var(--star-y, 0px) * 0.5));
  }
  70% {
    opacity: 1;
    transform: scale(1) translate(var(--star-x, 0px), var(--star-y, 0px));
  }
  100% {
    opacity: 0;
    transform: scale(0.5) translate(var(--star-x, 0px), var(--star-y, 0px));
  }
}
@keyframes mi-charlie-save-spin {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
}
@keyframes mi-charlie-typing {
  0%, 80%, 100% {
    transform: scale(0.6);
    opacity: 0.4;
  }
  40% {
    transform: scale(1);
    opacity: 1;
  }
}
.monsterinsights-ai-charlie-toast-enter-active,
.monsterinsights-ai-charlie-toast-leave-active {
  transition: opacity 0.3s ease, transform 0.3s ease;
}

.monsterinsights-ai-charlie-toast-enter-from,
.monsterinsights-ai-charlie-toast-leave-to {
  opacity: 0;
  transform: translateX(-50%) translateY(-8px);
}

textarea.monsterinsights-ai-charlie__popup-input-field {
  flex: 1;
  border: none;
  outline: none;
  font-size: 14px;
  line-height: 20px;
  color: #393f4c;
  background: transparent;
  padding: 0;
  margin: 0;
  resize: none;
  overflow: hidden;
  max-height: 120px;
}
textarea.monsterinsights-ai-charlie__popup-input-field::placeholder {
  color: #777;
}
textarea.monsterinsights-ai-charlie__popup-input-field:focus {
  outline: none;
  border: none;
  box-shadow: none;
}