<!-- wp:template-part {"slug":"header","tagName":"header"} /-->

<!-- wp:group {"tagName":"main","className":"is-style-ext-preset\u002d\u002dgroup\u002d\u002dnatural-1\u002d\u002dtemplate","style":{"spacing":{"blockGap":"3rem","padding":{"top":"var(\u002d\u002dwp\u002d\u002dcustom\u002d\u002dspacing\u002d\u002dmedium)","bottom":"var(\u002d\u002dwp\u002d\u002dcustom\u002d\u002dspacing\u002d\u002dmedium)"},"margin":{"top":"0px","bottom":"0px"}}}} -->
<main
  class="wp-block-group is-style-ext-preset--group--natural-1--template"
  style="margin-top:0px;margin-bottom:0px;padding-top:var(--wp--custom--spacing--medium);padding-bottom:var(--wp--custom--spacing--medium)">
	<!-- wp:group {"className":"ext-animate\u002d\u002don","style":{"spacing":{"blockGap":"2.5rem"}},"layout":{"inherit":true}} -->
	<div class="wp-block-group ext-animate--on">
		<!-- wp:group {"style":{"spacing":{"blockGap":"0.5rem"}},"layout":{"inherit":true}} -->
		<div class="wp-block-group">
			<!-- wp:post-title {"level":1,"isLink":true,"fontSize":"x-large"} /-->

			<!-- wp:post-date /-->
		</div>
		<!-- /wp:group -->

		<!-- wp:group {"metadata":{"name":"Featured Image"},"align":"wide","className":"is-style-ext-preset\u002d\u002dgroup\u002d\u002dnatural-1\u002d\u002ditem-card-1\u002d\u002dalign-start","style":{"spacing":{"padding":{"top":"0","bottom":"0","left":"0","right":"0"}}},"layout":{"type":"constrained"}} -->
			<div class="wp-block-group alignwide is-style-ext-preset--group--natural-1--item-card-1--align-start" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">
				<!-- wp:post-featured-image {"isLink":true,"aspectRatio":"16/9","align":"wide"} /-->
			</div>
		<!-- /wp:group -->
	</div>
	<!-- /wp:group -->

	<!-- wp:post-content {"layout":{"inherit":true}} /-->

	<!-- wp:group {"style":{"spacing":{"blockGap":"2.5rem"}},"layout":{"inherit":true}} -->
	<div class="wp-block-group">
		<!-- wp:group {"style":{"spacing":{"blockGap":"1.5rem"}},"layout":{"type":"flex"}} -->
		<div class="wp-block-group">
			<!-- wp:post-author {"showAvatar":false,"fontSize":"small"} /-->

			<!-- wp:post-terms {"term":"post_tag","fontSize":"small"} /-->
		</div>
		<!-- /wp:group -->

		<!-- wp:separator {"opacity":"css","className":"is-style-wide"} -->
		<hr class="wp-block-separator has-css-opacity is-style-wide" />
		<!-- /wp:separator -->

		<!-- wp:comments-query-loop -->
		<div class="wp-block-comments-query-loop">
			<!-- wp:comments-title /-->

			<!-- wp:comment-template -->
			<!-- wp:columns -->
			<div class="wp-block-columns">
				<!-- wp:column {"width":"40px"} -->
				<div class="wp-block-column" style="flex-basis:40px">
					<!-- wp:avatar {"size":40,"style":{"border":{"radius":"20px"}}} /-->
				</div>
				<!-- /wp:column -->

				<!-- wp:column -->
				<div class="wp-block-column">
					<!-- wp:comment-author-name /-->

					<!-- wp:group {"style":{"spacing":{"margin":{"top":"0px","bottom":"0px"}}},"layout":{"type":"flex"}} -->
					<div class="wp-block-group" style="margin-top:0px;margin-bottom:0px">
						<!-- wp:comment-date /-->

						<!-- wp:comment-edit-link /-->
					</div>
					<!-- /wp:group -->

					<!-- wp:comment-content /-->

					<!-- wp:comment-reply-link /-->
				</div>
				<!-- /wp:column -->
			</div>
			<!-- /wp:columns -->
			<!-- /wp:comment-template -->

			<!-- wp:comments-pagination -->
			<!-- wp:comments-pagination-previous /-->

			<!-- wp:comments-pagination-numbers /-->

			<!-- wp:comments-pagination-next /-->
			<!-- /wp:comments-pagination -->

			<!-- wp:post-comments-form /-->
		</div>
		<!-- /wp:comments-query-loop -->
	</div>
	<!-- /wp:group -->
</main>
<!-- /wp:group -->


<!-- wp:template-part {"slug":"footer","tagName":"footer"} /-->