<?php
/**
 * 404 Monitor inline help: "Screen Content" tab.
 *
 * @package    RankMath
 * @subpackage RankMath\Monitor
 */

defined( 'ABSPATH' ) || exit;

?>
<p>
	<?php esc_html_e( 'You can customize the display of this screen\'s contents in a number of ways:', 'seo-by-rank-math' ); ?>
</p>
<ul>
	<li><?php esc_html_e( 'You can hide/display columns based on your needs.', 'seo-by-rank-math' ); ?></li>
	<li><?php esc_html_e( 'You can decide how many items to list per screen using the Screen Options tab.', 'seo-by-rank-math' ); ?></li>
	<li><?php esc_html_e( 'You can search items using the search form at the top.', 'seo-by-rank-math' ); ?></li>
	<li><?php esc_html_e( 'You can reorder the list by clicking on the column headings. ', 'seo-by-rank-math' ); ?></li>
</ul>
