.monsterinsights-apex-chart[data-v-5e189bdf] {
  width: 100%;
}
.monsterinsights-apex-chart__empty[data-v-5e189bdf] {
  display: flex;
  align-items: center;
  justify-content: center;
  min-height: 200px;
  color: #999797;
  font-size: 14px;
}
.monsterinsights-overview-report-table__cell-loading[data-v-35a77760],
.monsterinsights-overview-report-table__cell-empty[data-v-35a77760] {
	text-align: center;
	padding: 2rem 1rem;
	color: var(--color-gray-600, #6b7280);
}
.monsterinsights-overview-report-table__cell-loading[data-v-35a77760] {
	display: flex;
	align-items: center;
	justify-content: center;
	gap: 0.5rem;
}
.monsterinsights-overview-report-table__demo-badge[data-v-35a77760] {
	display: inline-block;
	margin-left: 8px;
	padding: 1px 8px;
	font-size: 11px;
	font-weight: 500;
	line-height: 1.6;
	color: #6b7280;
	background-color: #f3f4f6;
	border: 1px solid #e5e7eb;
	border-radius: 4px;
	vertical-align: middle;
	letter-spacing: 0.02em;
}
.monsterinsights-not-authenticated-notice[data-v-cc9ee503] {
  width: 750px;
  max-width: 100%;
  margin: 60px auto 0;
  background: #fff;
  padding: 0 20px 20px;
  box-shadow: 0 5px 25px 0 rgba(0, 0, 0, 0.15);
  border: 1px solid #d6e2ed;
  text-align: center;
}
.monsterinsights-not-authenticated-notice h3[data-v-cc9ee503] {
  color: #393f4c;
  font-size: 20px;
  margin: 32px 0 20px;
  line-height: 1.4;
}
.monsterinsights-not-authenticated-notice p[data-v-cc9ee503] {
  font-size: 15px;
  line-height: 1.5;
  color: #444;
  margin: 0 0 20px;
}