.monsterinsights-metabox-input-checkbox {
	margin-top: 15px;
}

.monsterinsights-metabox-input-checkbox input[disabled] {
	cursor: not-allowed;
}

.monsterinsights-metabox-helper {
	font-size: 12px;
	line-height: 120%;
	color: #7D7D7D;
	margin-top: 16.5px;
}

.monsterinsights-metabox-pro-badge {
	margin-top: 15px;
	margin-bottom: 15px;
	padding: 15px;
	background: #EAFAEE;
	border: 1px solid #46BF40;
	display: flex;
	position: relative;
	line-height: 100%;
}

.monsterinsights-metabox-pro-badge span {
	color: #31862D;
	font-weight: bold;
	font-size: 13px;
	line-height: 100%;
	letter-spacing: -0.02em;
	padding-left: 20px;
}

.monsterinsights-metabox-pro-badge span svg {
	position: absolute;
	left: 15px;
}

.monsterinsights-metabox-pro-badge .monsterinsights-metabox-pro-badge-upgrade {
	text-align: right;
	flex: 1;
}

.monsterinsights-metabox-pro-badge .monsterinsights-metabox-pro-badge-upgrade a {
	font-size: 13px;
	color: #31862D;
	text-decoration: underline;
	display: block;
}

/*
***************************
** Page Insights in Meta **
***************************
*/

#monsterinsights-metabox-page-insights {
	margin-top: 24px;
	margin-bottom: 24px;
}

#monsterinsights_hide_page_insights {
	margin-top: 8px;
}

#monsterinsights-page-insights-content {
	display: none;
}

#monsterinsights-page-insights-content.active {
	display: block;
}

.monsterinsights-page-insights__tabs {
	display: grid;
	grid-template-columns: 1fr 1fr;
}

.monsterinsights-page-insights__tabs-tab {
	padding: 4px;
	color: var(--wp-admin-theme-color);
	font-style: normal;
	font-weight: 400;
	font-size: 13px;
	line-height: 16px;
	border-left: 1px solid transparent;
	border-right: 1px solid transparent;
	border-top: 1px solid transparent;
	border-bottom: 1px solid #C4C4C4;
	text-decoration: none;
	text-align: center;
	transition: 0.3s all ease-in-out;
}

.monsterinsights-page-insights__tabs-tab.active,
.monsterinsights-page-insights__tabs-tab:focus {
	color: #2C3338;
	border-left: 1px solid #C4C4C4;
	border-right: 1px solid #C4C4C4;
	border-top: 1px solid #C4C4C4;
	border-bottom: 1px solid transparent;
}

.monsterinsights-page-insights__tabs-tab:focus {
	outline: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}

.monsterinsights-page-insights-tabs-content {
	border-left: 1px solid #C4C4C4;
	border-right: 1px solid #C4C4C4;
	border-bottom: 1px solid #C4C4C4;
}

.monsterinsights-page-insights-tabs-content__tab {
	display: none;
	transition: 0.3s all ease-in-out;
}

.monsterinsights-page-insights-tabs-content__tab.active {
	display: block;
}

.monsterinsights-page-insights-tabs-content__tab-items {
	display: grid;
	grid-template-columns: 1fr 1fr;
	padding: 15px;
}

.monsterinsights-page-insights-tabs-content__tab-item {
	padding: 16px;
}

.monsterinsights-page-insights-tabs-content__tab-item__result {
	font-style: normal;
	font-weight: 500;
	font-size: 20px;
	line-height: 24px;
	color: #3C434A;
	position: relative;
}

.lite .monsterinsights-page-insights-tabs-content__tab-item__result span {
	filter: blur(3px);
}

.lite .monsterinsights-page-insights-tabs-content__tab-item__result:after {
	content: '';
	width: 10px;
	height: 14px;
	background: url("../images/restricted.svg") no-repeat center center;
	position: absolute;
	left: calc(40% - 5px);
	top: calc(50% - 7px);
}

.monsterinsights-page-insights-tabs-content__tab-item__title {
	font-style: normal;
	font-weight: 400;
	font-size: 12px;
	line-height: 14px;
	color: #7D7D7D;
	margin-top: 4px;
}

.monsterinsights-insights-draft {
	font-size: 12px;
	font-style: normal;
	padding: 16px;
	border: 1px solid #C4C4C4;
	margin-top: 8px;
	color: rgb(117, 117, 117);
}
