/* stylelint-disable */
/*
 * Alignment styles.
 * These rules are temporary, and should not be relied on or
 * modified too heavily by themes or plugins that build on
 * Twenty Twenty-Two. These are meant to be a precursor to
 * a global solution provided by the Block Editor.
 *
 * Relevant issues:
 * https://github.com/WordPress/gutenberg/issues/35607
 * https://github.com/WordPress/gutenberg/issues/35884
 */
.wp-site-blocks,
body > .is-root-container,
.edit-post-visual-editor__post-title-wrapper,
.wp-block-group.alignfull,
.wp-block-group.has-background,
.wp-block-cover.alignfull,
.is-root-container .wp-block[data-align="full"] > .wp-block-group,
.is-root-container .wp-block[data-align="full"] > .wp-block-cover {
	padding-left: clamp(1.5rem, 5vw, 2rem);
	padding-right: clamp(1.5rem, 5vw, 2rem);
}

.block-editor-block-list__layout.is-root-container > .alignfull,
.block-editor-block-list__layout.is-root-container > .alignfull > .alignfull,
.is-root-container > .wp-block-group.has-background,
.wp-site-blocks .alignfull,
.wp-site-blocks > .wp-block-group.has-background,
.wp-site-blocks > .wp-block-cover,
.wp-site-blocks > .wp-block-template-part > .wp-block-group.has-background,
.wp-site-blocks > .wp-block-template-part > .wp-block-cover,
body > .is-root-container > .wp-block-cover,
body
	> .is-root-container
	> .wp-block-template-part
	> .wp-block-group.has-background,
body > .is-root-container > .wp-block-template-part > .wp-block-cover,
.is-root-container .wp-block[data-align="full"] {
	margin-right: calc(clamp(1.5rem, 5vw, 2rem) * -1) !important;
	margin-left: calc(clamp(1.5rem, 5vw, 2rem) * -1) !important;
	width: unset;
}

/* Blocks inside columns don't have negative margins. */
.wp-site-blocks .wp-block-columns .wp-block-column .alignfull,
.is-root-container .wp-block-columns .wp-block-column .wp-block[data-align="full"],
/* We also want to avoid stacking negative margins. */
.wp-site-blocks .alignfull:not(.wp-block-group) .alignfull,
.is-root-container .wp-block[data-align="full"]>*:not(.wp-block-group) .wp-block[data-align="full"] {
	margin-left: auto !important;
	margin-right: auto !important;
	width: inherit;
}

/*
 * Search and File Block button styles.
 * Necessary until the following issues are resolved in Gutenberg:
 * https://github.com/WordPress/gutenberg/issues/36444
 * https://github.com/WordPress/gutenberg/issues/27760
 */

.wp-block-search__button,
.wp-block-file .wp-block-file__button {
	background-color: var(--wp--preset--color--primary);
	border-radius: 0;
	border: none;
	color: var(--wp--preset--color--background);
	padding: calc(0.667em + 2px) calc(1.333em + 2px);
}

/*
  * Button hover styles.
  * Necessary until the following issue is resolved in Gutenberg:
  * https://github.com/WordPress/gutenberg/issues/27075
  */

.wp-block-search__button:hover,
.wp-block-file .wp-block-file__button:hover,
.wp-block-button__link:hover {
	opacity: 0.9;
}

/* Responsive menu animation and customization.
----------------------------------------------------------*/
@media (max-width: 599px) {
	.wp-block-navigation__responsive-container {
		display: block !important;
		opacity: 0;
		transform: translateX(200px);
		transition: transform 170ms ease-in-out, opacity 150ms ease-in-out;
		visibility: hidden;
	}

	.wp-block-navigation__responsive-container[aria-hidden="false"] {
		opacity: 1;
		transform: translateX(0);
		visibility: visible;
	}
}
